;; Generated package description from xpm.el  -*- no-byte-compile: t -*-
(define-package "xpm" "1.0.5" "edit XPM images" '((cl-lib "0.5") (queue "0.2")) :commit "85e5c412dde7ec3c3f64c64d37079e233293e4d0" :authors '(("Thien-Thi Nguyen" . "ttn@gnu.org")) :maintainer '("Thien-Thi Nguyen" . "ttn@gnu.org") :keywords '("multimedia" "xpm") :url "https://www.gnuvola.org/software/xpm/")
